@@ -1,8 +1,8 @@
 #![feature(array_chunks)]
 
-mod matrix;
+pub mod matrix;
 use matrix::*;
-mod raw_data;
+pub mod raw_data;
 use raw_data::*;
 
 /// holds parsed idx file data
